@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2016-01-23'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use 5.010001;
 use strict;
@@ -299,6 +299,7 @@ sub complete_cli_arg {
     for my $ospec (keys %$gospec) {
         my $res = Getopt::Long::Util::parse_getopt_long_opt_spec($ospec)
             or die "Can't parse option spec '$ospec'";
+        next if $res->{is_arg};
         $res->{min_vals} //= $res->{type} ? 1 : 0;
         $res->{max_vals} //= $res->{type} || $res->{opttype} ? 1:0;
         for my $o0 (@{ $res->{opts} }) {
@@ -588,7 +589,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.39 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-01-07.
+This document describes version 0.40 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-01-23.
 
 =head1 SYNOPSIS
 
@@ -736,6 +737,22 @@ Return value:  (hash|array)
 You can use C<format_completion> function in C<Complete::Bash> module to format
 the result of this function for bash.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Complete-Getopt-Long>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Getopt-Long>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Getopt-Long>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Getopt::Long::Complete>
@@ -750,22 +767,6 @@ L<Getopt::Complete>.
 L<Perinci::CmdLine> - an alternative way to easily create command-line
 applications with completion feature.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Complete-Getopt-Long>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Complete-Getopt-Long>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Getopt-Long>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
